@@ -2,10 +2,8 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import account
-from . import product
-from . import sale
-from . import stock
+
+from . import account, product, sale, stock
 
 __all__ = ['register']
 
@@ -29,5 +27,15 @@ def register():
     Pool.register(
         module='sale_gift_card', type_='wizard')
     Pool.register(
+        sale.GiftCardReport,
         sale.GiftCardEmail,
         module='sale_gift_card', type_='report')
+    Pool.register(
+        sale.GiftCard_POS,
+        sale.POSSale,
+        sale.POSSaleLine,
+        sale.POSPayGiftCard,
+        module='sale_gift_card', type_='model', depends=['sale_point'])
+    Pool.register(
+        sale.POSPay,
+        module='sale_gift_card', type_='wizard', depends=['sale_point'])
